@@ -1,5 +1,5 @@
 package Image::PNG::Const;
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -1255,24 +1255,29 @@ all the symbols in this module:
 
 This Perl module was generated from C<png.h>.
 
+
 =head1 AUTHOR
 
 Ben Bullock, <bkb@cpan.org>
 
+=head2 Request
+
+If you'd like to see this module continued, let me know that you're
+using it. For example, send an email, write a bug report, star the
+project's github repository, add a patch, add a C<++> on Metacpan.org,
+or write a rating at CPAN ratings. It really does make a
+difference. Thanks.
+
 =head1 COPYRIGHT & LICENCE
 
-The Image::PNG::Libpng package and associated files are copyright (C)
-2016 Ben Bullock.
+This package and associated files are copyright (C) 
+-2016
+Ben Bullock.
 
-You can use, copy, modify and redistribute Image::PNG::Libpng and
-associated files under the Perl Artistic Licence or the GNU General
-Public Licence.
+You can use, copy, modify and redistribute this package and associated
+files under the Perl Artistic Licence or the GNU General Public
+Licence.
 
-=head1 SUPPORT
-
-=head2 Reporting a bug
-
-There is a bug tracker at L<https://github.com/benkasminbullock/image-png-libpng/issues>.
 
 
 
